# SET VERSION HERE !!!
%define major 1
%define minor 8.1
%define librelease 1

%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define staticname %mklibname %{name} -d -s

Summary:	The Irrlicht Engine SDK
Name:		irrlicht
Version:	%{major}.%{minor}
Release:	%mkrel 1
License:	Zlib
Group:		Graphics
URL:		http://irrlicht.sourceforge.net/
Source: 	http://prdownloads.sourceforge.net/irrlicht/%{name}-%{version}.zip
Patch1:		%{name}-1.8-library-makefile.patch
Patch2:		%{name}-1.8-use-system-libs.patch
Patch3:		%{name}-1.8-GUIEditor-makefile.patch
Patch4:		%{name}-1.8-IrrFontTool-makefile.patch
Patch5:		%{name}-1.8.1-mga-system-glext.patch
Patch6:		%{name}-1.8.1-fdr-mesa10.patch
BuildRequires:	imagemagick
BuildRequires:	zlib-devel
BuildRequires:	libjpeg-devel
BuildRequires:	libpng-devel
BuildRequires:	mesagl-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	libxext-devel
BuildRequires:	libxxf86vm-devel
BuildRequires:	libxft-devel
BuildRequires:	bzip2-devel
BuildRequires:	fontconfig-devel
BuildRequires:	libxcursor-devel
Requires:	%{name}-media = %{version}-%{release}

%description
The Irrlicht Engine is an open source high performance realtime
3D engine written and usable in C++ and also available for .NET
languages. It is completely cross-platform, using D3D, OpenGL
and its own software renderer, and has all of the state-of-the-art
features which can be found in commercial 3D engines.

We've got a huge active community, and there are lots of projects
in development that use the engine. You can find enhancements for
Irrlicht all over the web, like alternative terrain renderers,
portal renderers, exporters, world layers, tutorials, editors,
language bindings for java, perl, ruby, basic, python, lua, and so
on. And best of all: It's completely free.

%package -n %{libname}
Summary:	Shared libraries for Irrlicht 3D engine
Group:		System/Libraries

%description -n %{libname}
Shared libraries for Irrlicht 3D engine.

%package -n %{develname}
Summary:	Development files for Irrlicht 3D engine
Group:		Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for Irrlicht 3D engine.

%package -n %{staticname}
Summary:	Static files for Irrlicht 3D engine
Group:		Development/C
Requires:	%{develname}  = %{version}-%{release}

%description -n %{staticname}
Static files for Irrlicht 3D engine.

%package examples
Summary:	Demos and examples for the Irrlicht 3D engine
Group:		Graphics
Requires:	%{libname} = %{version}-%{release}

%description examples
Demos and examples for the Irrlicht 3D engine.

%package media
Summary:	Media files for Irrlicht 3D engine
Group:		Graphics
Requires:	%{name} = %{version}-%{release}

%description media
Media files needed by Irrlicht tools and demos.

%package doc
Summary:	User documentation for the Irrlicht 3D engine
Group:		Graphics
BuildArch:	noarch

%description doc
User documentation for the Irrlicht 3D engine.

%prep
%setup -q
%apply_patches

# clean Mac/Windows/Phone repository
find examples/ -maxdepth 1 -iname '*window' -or -iname '*mac*' -or -iname '*mobile' | xargs -exec rm -Rvf {} \;
find source/Irrlicht -maxdepth 1 -iname 'macos*' -exec rm -Rvf {} \;

# clean Demo as it needs irrKlang
rm -rf examples/Demo
sed -i -e 's|Demo||g' examples/buildAllExamples.sh

# make readme.txt utf8
sed -i 's/\r//' readme.txt
iconv -o readme.txt.iso88591 -f iso88591 -t utf8 readme.txt
mv readme.txt.iso88591 readme.txt

# clean all '\r' in files
for i in include/*.h doc/upgrade-guide.txt source/Irrlicht/*.cpp source/Irrlicht/*.h  source/Irrlicht/Makefile; do
    sed -i 's/\r//' $i
    chmod -x $i
    touch -r changes.txt $i
done

# https://bugzilla.redhat.com/show_bug.cgi?id=1035757
sed -i -e '/_IRR_MATERIAL_MAX_TEXTURES_/s/4/8/' include/IrrCompileConfig.h

%build
%setup_compile_flags
export LIBDIR="%{_libdir}"
export PREFIX="%{_prefix}"
export INCLUDEDIR="%{_includedir}"

# use system wide libs, see patch2
rm -rf source/Irrlicht/{jpeglib,zlib,libpng,bzip2}
find source/Irrlicht -name '*.cpp' | xargs sed -i -e 's|zlib/zlib.h|zlib.h|g' -e 's|libpng/png.h|png.h|g' -e 's|jpeglib/jerror.h|jerror.h|g' -e 's|jpeglib/jpeglib.h|jpeglib.h|g'
find source/Irrlicht -name '*.h' | xargs sed -i -e 's|jpeglib/jpeglib.h|jpeglib.h|g' -e 's|libpng/png.h|png.h|g' -e 's|jpeglib/jerror.h|jerror.h|g'

# media path
sed -i -e 's|../../media/|%{_datadir}/irrlicht/|g' tools/GUIEditor/main.cpp
find ./examples -name *.cpp | xargs sed -i -e 's|../../media/|%{_datadir}/irrlicht/|g'

# build static library
%make -C source/Irrlicht \
    CFLAGS="%{optflags}" \
    CXXFLAGS="%{optflags}" \
    LDFLAGS="%{ldflags}"

# clean it
%make -C source/Irrlicht clean

# build shared library
%make -C source/Irrlicht sharedlib NDEBUG=1 \
    %ifnarch ix86
    CFLAGS="%{optflags} -fPIC" \
    CXXFLAGS="%{optflags} -fPIC" \
    LDFLAGS="%{ldflags}"
    %else
    CFLAGS="%{optflags}" \
    CXXFLAGS="%{optflags}" \
    LDFLAGS="%{ldflags}"
    %endif

# create necessary links to avoid linker-error for tools/examples
pushd lib/Linux
ln -s libIrrlicht.so.%{major}.%{minor}.%{librelease} libIrrlicht.so
ln -s libIrrlicht.so.%{major}.%{minor}.%{librelease} libIrrlicht.so.%{major}
popd

# build tools
pushd tools
pushd GUIEditor
%make CFLAGS="%{optflags}" CXXFLAGS="%{optflags} -ffast-math" LDFLAGS="%{ldflags}"
popd
pushd IrrFontTool/newFontTool
%make CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" LDFLAGS="%{ldflags}"
popd
popd

# build examples
pushd examples
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
export LDFLAGS="%{ldflags}"
sh buildAllExamples.sh
popd

%install
mkdir -p %{buildroot}%{_libdir}
install -m 0644 lib/Linux/libIrrlicht.a %{buildroot}%{_libdir}
install -m 0755 lib/Linux/libIrrlicht.so.%{major}.%{minor}* %{buildroot}%{_libdir}

pushd %{buildroot}%{_libdir}
ln -s libIrrlicht.so.%{major}.%{minor} libIrrlicht.so
popd

# includes
mkdir -p %{buildroot}%{_includedir}/%{name}
cp -f include/*.h %{buildroot}%{_includedir}/%{name}

# tools
install -m 0755 bin/Linux/GUIEditor -D %{buildroot}%{_bindir}/%{name}-GUIEditor
install -m 0755 bin/Linux/FontTool -D %{buildroot}%{_bindir}/%{name}-FontTool

# examples-docs
pushd examples
install -dm 0755 %{buildroot}%{_docdir}/Irrlicht-examples

ex_dir=`find . -name tutorial.html`
for i in $ex_dir; do
	dir_name=`dirname $i`
	install -dm 0755 %{buildroot}%{_docdir}/Irrlicht-examples/$dir_name
	install -m 0644 $i %{buildroot}%{_docdir}/Irrlicht-examples/$dir_name
done
popd

# media and icon
mkdir -p %{buildroot}%{_datadir}/%{name}
install -m 0755 media/* %{buildroot}%{_datadir}/%{name}
install -m 0755 media/irrlichtlogo2.png -D %{buildroot}%{_iconsdir}/hicolor/128x128/apps/%{name}.png

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}-GUIEditor.desktop << EOF
[Desktop Entry]
Name=Irrlicht GUI Editor
Comment=
Exec=%{name}-GUIEditor
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=Graphics;3DGraphics;X-MandrivaLinux-Multimedia-Graphics;
EOF

cat > %{buildroot}%{_datadir}/applications/%{name}-FontTool.desktop << EOF
[Desktop Entry]
Name=Irrlicht Font Tool
Comment=
Exec=%{name}-FontTool
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=Graphics;3DGraphics;X-MandrivaLinux-Multimedia-Graphics;
EOF

%files
%{_bindir}/%{name}-GUIEditor
%{_bindir}/%{name}-FontTool
%{_datadir}/applications/*.desktop
%{_iconsdir}/hicolor/*/apps/*.png

%files -n %{libname}
%{_libdir}/lib*.so.%{major}*

%files -n %{develname}
%dir %{_includedir}/%{name}
%{_libdir}/lib*.so
%{_includedir}/%{name}/*.h

%files -n %{staticname}
%{_libdir}/lib*.a

%files examples
%dir %{_docdir}/Irrlicht-examples
%{_docdir}/Irrlicht-examples/*

%files media
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*

%files doc
%doc doc/*


%changelog
* Thu Aug 14 2014 pinoc <vogtpet at gmail.com> 1.8.1-1pclos2014
- reimported irrlicht

